@@ -18,12 +18,6 @@ class ONTSwapStatus(enum.Enum):
     failed = 'failed'
 
 
-class NotificationSendType(enum.Enum):
-    task_registered = 'task_registered'
-    task_success = 'task_success'
-    task_failed = 'task_failed'
-
-
 class ONT(Base):
     __tablename__ = 'ont'
 
@@ -107,16 +101,21 @@ class ONTSWAP(Base):
     old_siteid = Column(Integer, nullable=False)
     old_olt_ip = Column(INET, nullable=False)
     old_sitename = Column(String(length=256), nullable=False)
+    new_olt_ip = Column(INET, nullable=False)
+    new_siteid = Column(Integer, nullable=False)
+    new_sitename = Column(String(length=256), nullable=False)
+    new_site_shortname = Column(String(length=12), nullable=False)
     old_ucr = Column(String(length=64), nullable=False)
     old_ont_register_datetime = Column(DateTime)
-    old_ont_expunged = Column(Boolean)
+    old_service_provision_datetime = Column(DateTime)
+    old_ont_expunged = Column(Boolean, default=False)
     old_ont_expunge_datetime = Column(DateTime)
-    new_db_record_created = Column(Boolean)
+    new_db_record_created = Column(Boolean, default=False)
     new_db_record_created_datetime = Column(DateTime)
     user = Column(String(length=256), nullable=False, comment='user who requested the swap')
     task_request_datetime = Column(DateTime)
     task_finish_datetime = Column(DateTime)
-    notification_sent_type = Column(Enum(NotificationSendType))
+    notification_sent_type = Column(String(length=24))
     notification_sent_datetime = Column(DateTime)
     error = Column(String(length=256))
 
